No.1 G2 MTK2502 Waterproof Bluetooth 4.0 Smart Watch with Heart Rate Monitor, Pedometer & Call Function (Black) - MT0607B
Description: This No.1 G2 MTK2502 Waterproof Bluetooth 4.0 Smart Watch with Heart Rate Monitor, Pedometer & Call Function (Black) US$ 69.99 is really your best choice to keep in touch with your family and friends.

Holiday Notice: We will take Spring Festival holiday from Feb. 17 to Feb. 19, 2015 (PST). You still can place order on our website during period. Sorry for any inconvenience this may cause and wish you a happy shopping.

- Language
- Currency US$

- Customer Service
- My Account
- Order Tracking
- Sign in or Register
- Welcome! User Sign out

Power Bank VK700 PRO HUD Display Bluetooth Camera Cigarette Lighter RC
Cart( 0 )
All Categories
SAVE 20%
View Larger
View Video

# No.1 G2 MTK2502 Waterproof Bluetooth 4.0 Smart Watch with Heart Rate Monitor, Pedometer & Call Function (Black)

SKU: MT0607B
3/5(21 reviews)
5 star : 14 (66%)
4 star : 7 (33%)
3 star : 0
2 star : 0
1 star : 0

See all 21 reviews Write a review

Diggs(113)
20% OFF 12/16/2015 23:59:59 Price:
US$ 55.99

  US$US Dollar
  €Euro
  £British Pound
  R$Brazilian Real
  CA$Canadian Dollar
  AU$Australian Dollar
  SGD$Singapore Dollar
  NOK$Norwegian Krone
  CHF Swiss Franc
  HK$Hong Kong Dollar

US$ 69.99

Usually will be shipped in 2-3 days

Worldwide Free Shipping

Payment & Returns
Quantity: Unit(s)

Add to wish list Error Report Price Match

This Bluetooth smartwatch featuring stylish look supports heart rate monitor, music player, SMS/Weichat notification, pedometer, stopwatch, anti-theft alarm, receieving and answering call, etc.

- Item Description
- Questions & Answers
- Payment & Shipping

Features
1.54" Mipi TFT capacitive touch High performance MTK2502 CPU Supports notification (SMS, wechat, facebook, whatAPP, etc.) Features calls, pedometer and heart rate monitoring function Supports Bluetooth 4.0, 2MP camera and Waterproof IP67 Equipped with sapphire 2 lenses, high resistance to wear Also supports anti-lost, sedentary reminder, alarm clock, calendar, smartphome control, Infrared, recods, video and stopwatch, etc. Compatible with all smartphones with Bluetooth V4.0/3.0 and phones supporting iOS/Android/WIN System
General Specs |
Brand & Model | No.1 G2
LCD | 1.54" Mipi TFT Capacitive screens (TP laminating technology)
Camera | 2.0MP
CPU | MTK2502
Bluetooth | Bluetooth 4.0
Battery | 350mAh
Standby Time | Approx. 70 hours
Talk Time | Approx.3 hours
Waterproof | IP67
Anti-friction | Sapphire lens
Language | English, Russian, French, German, Italian, Spanish, Traditional Chinese, Portuguese(Portugal), Portuguese (Brazilian)
Dimension | 43 x 37 x 8 mm
Weight | 65g

Package Details
Weight: 220.42 g
Size: 10*8.5*7.6 cm

Credit Card

1, Please key in the correct shipping address in English while checking out with PayPal. Or the order will be shipped to your PayPal address.
2, If your home address (habitually receiving address) has been changed, please edit your PayPal address in time to avoid editing receiving address repeatedly while checking out with PayPal.
3, Normally, dropshipping order will be shipped out in 1 business day and non-dropshipping order 2 business days.

Shipping Method

Item | Area | Delivery time | Delivery time
In Peak Season
Standard | United States, Canada | 15-20 calendar day | 25-30 calendar days
Australia, New Zealand, Singapore, Vietnam, Malaysia, Israel,Indonesia, Turkey | 20-25 calendar days | 30-35 calendar days
Russia, United Kingdom, France, Spain, Germany, Netherlands, Spain, Ukraine, Japan, Belgium, Denmark, Finland, Ireland, Norway, Portugal, Sweden, Switzerland | 25-30 calendar days | 35-40 calendar days
Italy, Brazil, Argentina, Chile, Mexico | 30-40 calendar days | 40-50 calendar days
Priority | United States, United Kingdom,Russia,Australia | 7-15 calendar days | 15-25 calendar days
Express | 3-7 calendar days worldwide

What other people are saying
FocalPrice does not endorse, recommend or sponsor any guest product reviews.
5 star : 14 (66%)
4 star : 7 (33%)
3 star : 0
2 star : 0
1 star : 0
Average Rating: 5.0
21 customer reviews Write a Review, Post Images, or Post Videos, and get Focal Points.

#### Daily Deals

- E14-56SMD-W E14 12W AC220-240V 6000-6500K 56-SMD White LED Corn Light

  US$ 3.49 US$ 5.09

- MR-10 Mini Portable FM Radio Speaker MP3 Player with TF Card Slot (Gray)

  US$ 12.99 US$ 14.59

- Magic 360-degree Rotation LED Flashing Ball Light

  US$ 14.39 US$ 19.09

- Minions Design Remote Control Flying Toy with Automatic Suspension, Infrared Sensor & Intelligent Recognition (Black)

  US$ 8.69 US$ 9.69

- ASUS PadFone mini 2-in-1 Set 4.0" Smartphone + 7.0" Tablet (Black)

  US$ 149.99 US$ 232.09

Your Recent History Clear

﻿ ﻿